@@ -36,7 +36,7 @@ sub handle {
   my $cpath = $context->{contextpath};
   #print "Context path=$cpath\n";
   # scrub path (badly): XXX fix this with file::spec or the like
-  if ( $cpath =~ m[(^|/)\.\.(/|$)] ) {
+  if ( $cpath =~ m[(^|/)..(/|$)] ) {
     warn "Will not serve dangerous path '$cpath'\n"; # should keep silent here
     return H_CONT;
   }
@@ -57,7 +57,6 @@ sub handle_plainfile {
   my $filepath = shift;
   my $context = shift;
   if ( open(my $in, $filepath) ) {
-    binmode($in);
     local $/ = undef;
     $context->{response}->code( RC_OK );
     my $type = $self->{mimetypes}->mimeTypeOf( $filepath );
